Data Science oriented tools, mostly for Apache Spark

- The pipepline for using Python ML models together with Apache Spark
- Command-line tools (see [readme](bin/README.md))
- *demo*: usage demos in form of Jupyter notebooks
  - model inference on cluster: [demo/score-sklearn.ipynb](demo/score-sklearn.ipynb)
  - quick dataset distribution change detection: [demo/datadiff.ipynb](demo/datadiff.ipynb)
